/** Main file for Wochabit
  * Copyright (C) 2021 Ngô Ngọc Đức Huy
  *
  * This file is part of Wochabit.
  *
  * Wochabit is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation, either version 3 of the License, or
  * (at your option) any later version.
  *
  * Wochabit is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
  * along with Wochabit.  If not, see <https://www.gnu.org/licenses/>.
  * */
#include <errno.h>
#include <stdio.h>
#include <string.h>
#include <time.h>

#include "constants.h"
#include "config.h"
#include "date.h"

void print_status(int status); // Print the status for a day of a habit
void print_habit(int habit); // Print the habit stati during the tracked duration
 // Like print_habit, but for all habits from the tracker file
void print_habits(const char *fname);

void
print_status(int status)
{
	if (status) {
		printf(COLOR_PREFIX, DONE_COLOR);
		printf(DONE_CHAR);
	} else {
		printf(COLOR_PREFIX, FAIL_COLOR);
		printf(FAIL_CHAR);
	}
	printf(COLOR_SUFFIX);
}

void
print_habit(int habit)
{
	for (int i = 0; i < TRACK_LENGTH; ++i) {
		int status = habit % 2;
		print_status(status);
		habit >>= 1;
	}
	printf("\n");
}

void
print_habits(const char *fname)
{
	FILE *fp;
	char date_buf[DATE_SIZE];
	fp = fopen(fname, "r");
	if (fp == NULL) {
		fprintf(stderr, "Cannot read file %s: %s", fname,
				strerror(errno));
	}
}

int
main(int argc, char *argv[]){
	print_habit(5);
	print_habit(49);
	print_habit(1 << TRACK_LENGTH - 2);
	print_days();
	struct tm date = parse_date("2020-11-19");
	printf("%d\n", date.tm_year);
	printf("%d\n", date.tm_mon);
	printf("%d\n", date.tm_mday);
	int diff = get_day_diff(&date);
	printf("%d\n", diff);
	printf("Bye\n");
	return 0;
}
